# -*- coding: utf-8 -*-

""" Copy + Paste in X11
"""

import subprocess
from .base import *


def copy(string, xsel=False):
    """Copy given string into system clipboard. If 'xsel' is True, this
    will also copy into the primary x selection for middle click."""
    try:
        _cmd = ["xclip", "-selection", "clipboard"]
        subprocess.Popen(_cmd, stdin=subprocess.PIPE).communicate(
                string.encode('utf-8'))
        if xsel:
            _cmd = ["xclip", "-selection", "primary"]
            subprocess.Popen(_cmd, stdin=subprocess.PIPE).communicate(
                    string.encode('utf-8'))
    except OSError as why:
        raise XclipNotFound

def paste(xsel=False):
    """Returns system clipboard contents."""
    selection = "primary" if xsel else "clipboard"
    try:
        return subprocess.Popen(["xclip", "-selection", selection, "-o"], stdout=subprocess.PIPE).communicate()[0].decode("utf-8")
    except OSError as why:
        raise XclipNotFound




# -*- coding: utf-8 -*-

""" Copy + Paste in OS X
"""


import subprocess
import os

from .base import *


def copy(string, **kwargs):
    """Copy given string into system clipboard."""
    try:
        subprocess.Popen(['pbcopy'], stdin=subprocess.PIPE).communicate(
                string.encode("utf-8"))
    except OSError as why:
        raise XcodeNotFound

    return

def paste(**kwargs):
    """Returns system clipboard contents."""
    try:
        #Tell the IO system to decode IPC IO with utf-8,
        #to prevent UnicodeDecodeErrors on python3
        os.environ['LANG'] = 'en_US.utf-8'
        return subprocess.Popen(
            ['pbpaste'], stdout=subprocess.PIPE).communicate()[0].decode('utf-8')

    except OSError as why:
        raise XcodeNotFound

